@@ -11,7 +11,7 @@ class telegram:
         self.raise_error = raise_error
         self.resend_repeat_errors = resend_repeat_errors
         self.last_error = None
-    def send(self, title, exception=None):
+    def send(self, title='Error', exception=None):
         if self.full_error:
             error = traceback.format_exc()
         else:
